@@ -141,7 +141,7 @@ class Sensor:
 
     @property
     def serialnumber(self):
-        """  compatibility """
+        """compatibility"""
         return self.serial_number
 
 
@@ -154,13 +154,20 @@ class SPISensor(Sensor):
     _serial_mode = "SPI"
     device = None
 
-    def __init__(self, bus: "SpiController", cs: int, sensor_id: str = None):
+    def __init__(
+        self,
+        bus: "SpiController",
+        cs: int,
+        sensor_id: str = None,
+        loglvl: int = logging.WARNING,
+    ):
         self.cs = int(cs)
         self.bus = bus
         self.sensor_type = self.__name__
         self.sensor_id = sensor_id
         self.ftdi_serial = bus.ftdi.usb_dev.serial_number
         self._logger = logging.getLogger(self.__str__())
+        self._logger.setLevel(loglvl)
 
     def default_data(self):
         data = super().default_data()
@@ -283,7 +290,13 @@ class I2CSensor(Sensor):
     mux = MUX(None, None)
     _SENSOR_ADDRESS = -1
 
-    def __init__(self, bus: "I2cController", mux: "MUX", mux_port: int):
+    def __init__(
+        self,
+        bus: "I2cController",
+        mux: "MUX",
+        mux_port: int,
+        loglvl: int = logging.WARNING,
+    ):
         """
         Base class for all I2C Sensors
         :param bus: (core.i2controler.MMS_I2CController) sensor bus object
@@ -296,6 +309,8 @@ class I2CSensor(Sensor):
         self.mux_port = mux_port
         self.mux = mux
         self._logger = logging.getLogger(self.__str__())
+        self._logger.setLevel(loglvl)
+        self.mux._logger.setLevel(loglvl)
 
     def default_data(self):
         """
@@ -504,7 +519,7 @@ class UARTSensor(Sensor):
 
     @staticmethod
     def find_port(ftdi_serial):
-        """ For a given ftdi_serial number find the correct dev/ path """
+        """For a given ftdi_serial number find the correct dev/ path"""
         all_comports = list_ports.comports()
         for cp in all_comports:
             if cp.serial_number == ftdi_serial:
