@@ -14,8 +14,6 @@ import time
 from pyftdi.i2c import I2cNackError, I2cIOError
 import logging
 
-# logging.basicConfig(level=logging.DEBUG)
-
 
 class TCA9548:
     # Supported adress space
@@ -27,13 +25,13 @@ class TCA9548:
     # Maximum number of communication attempts
     __MAX_ATTEMPTS = 10
 
-    def __init__(self, bus, addr, **kwargs):
+    def __init__(self, bus, addr, loglvl=logging.INFO, **kwargs):
         self.bus = bus
         self.address = addr
         self._state = None
         if self.address and bus:
             self._logger = logging.getLogger(str(self))
-            self._logger.disabled = True
+            self._logger.setLevel(loglvl)
 
     def __str__(self):
         if self.address:
@@ -181,6 +179,8 @@ class TCA9548:
 
         self.open_single_port(port)
         state = self.send(port, addr, cmd)
+
+        self._logger.debug(f"{cmd} -> {addr:02x}h")
         if not state:
             data = None
             self._logger.error("Failed to write %s to %s@%s", cmd, port, addr)
@@ -204,6 +204,7 @@ class TCA9548:
             ba = self.bus.read(addr, readlen=readlength)
             self.byte_logger(ba, port, addr, sep="<-")
             time.sleep(self.__DELAY)
+            self._logger.debug(f"{addr:02x}h -> {ba}")
             return ba
         except (I2cNackError, I2cIOError):
             self._logger.error("Failed to read from %s@%s", port, addr)
