@@ -90,6 +90,8 @@ class MAX31865(SPISensor):
             raise ValueError("Wires must be a value of 2, 3, or 4!")
 
         config = self.read_u8(self._CONFIG_REG)
+        if config is None:
+            raise SpiIOError("Unable to read config.")
         if self.wires == 3:
             config |= self._CONFIG_3WIRE
         else:
@@ -107,7 +109,7 @@ class MAX31865(SPISensor):
         """
         try:
             self.setup()
-        except SpiIOError:
+        except (SpiIOError, ValueError):
             return False
         temperature = self.temperature
         if temperature is None:
